@@ -16,13 +16,15 @@
 import abc
 
 from oslo_config import cfg
+from oslo_log import log
 import six
 import stevedore
 
-from ironic_inspector.common.i18n import _
+from ironic_inspector.common.i18n import _, _LW
 
 
 CONF = cfg.CONF
+LOG = log.getLogger(__name__)
 
 
 @six.add_metaclass(abc.ABCMeta)
@@ -48,9 +50,7 @@ class ProcessingHook(object):  # pragma: no cover
 
         :param introspection_data: processed data from the ramdisk.
         :param node_info: NodeInfo instance.
-        :param kwargs: used for extensibility without breaking existing hooks,
-                       currently deprecated arguments node_patches and
-                       ports_patches are provided here.
+        :param kwargs: used for extensibility without breaking existing hooks.
         :returns: nothing.
 
         [RFC 6902] - http://tools.ietf.org/html/rfc6902
@@ -118,6 +118,9 @@ class RuleConditionPlugin(WithValidation):  # pragma: no cover
 class RuleActionPlugin(WithValidation):  # pragma: no cover
     """Abstract base class for rule action plugins."""
 
+    FORMATTED_PARAMS = []
+    """List of params will be formatted with python format."""
+
     @abc.abstractmethod
     def apply(self, node_info, params, **kwargs):
         """Run action on successful rule match.
@@ -146,6 +149,12 @@ _CONDITIONS_MGR = None
 _ACTIONS_MGR = None
 
 
+def missing_entrypoints_callback(names):
+    """Raise MissingHookError with comma-separated list of missing hooks"""
+    missing_names = ', '.join(names)
+    raise MissingHookError(missing_names)
+
+
 def processing_hooks_manager(*args):
     """Create a Stevedore extension manager for processing hooks.
 
@@ -161,6 +170,7 @@ def processing_hooks_manager(*args):
             names=names,
             invoke_on_load=True,
             invoke_args=args,
+            on_missing_entrypoints_callback=missing_entrypoints_callback,
             name_order=True)
     return _HOOKS_MGR
 
@@ -194,4 +204,14 @@ def rule_actions_manager():
         _ACTIONS_MGR = stevedore.ExtensionManager(
             'ironic_inspector.rules.actions',
             invoke_on_load=True)
+        for act in _ACTIONS_MGR:
+            # a trick to detect if function was overridden
+            if "rollback" in act.obj.__class__.__dict__:
+                LOG.warning(_LW('Defining "rollback" for introspection rules '
+                                'actions is deprecated (action "%s")'),
+                            act.name)
     return _ACTIONS_MGR
+
+
+class MissingHookError(KeyError):
+    """Exception when hook is not found when processing it."""
